@@ -28,6 +28,7 @@ pub mod state;
 pub mod tcp_port;
 pub mod threads;
 pub mod tree;
+pub mod tree_slot;
 pub mod tty;
 pub mod udp_port;
 pub mod uid;
@@ -72,6 +73,7 @@ pub use self::state::State;
 pub use self::tcp_port::TcpPort;
 pub use self::threads::Threads;
 pub use self::tree::Tree;
+pub use self::tree_slot::TreeSlot;
 pub use self::tty::Tty;
 pub use self::udp_port::UdpPort;
 pub use self::uid::Uid;
@@ -87,7 +89,7 @@ pub use self::vm_size::VmSize;
 pub use self::write_bytes::WriteBytes;
 
 use crate::column::Column;
-use lazy_static::lazy_static;
+use once_cell::sync::Lazy;
 use serde_derive::{Deserialize, Serialize};
 use std::collections::HashMap;
 
@@ -126,6 +128,7 @@ pub enum ConfigColumnKind {
     TcpPort,
     Threads,
     Tree,
+    TreeSlot,
     Tty,
     UdpPort,
     Uid,
@@ -187,6 +190,7 @@ pub fn gen_column(
         ConfigColumnKind::TcpPort => Box::new(TcpPort::new(header)),
         ConfigColumnKind::Threads => Box::new(Threads::new(header)),
         ConfigColumnKind::Tree => Box::new(Tree::new(tree_symbols)),
+        ConfigColumnKind::TreeSlot => Box::new(TreeSlot::new()),
         ConfigColumnKind::Tty => Box::new(Tty::new(header)),
         ConfigColumnKind::UdpPort => Box::new(UdpPort::new(header)),
         ConfigColumnKind::Uid => Box::new(Uid::new(header, abbr_sid)),
@@ -208,102 +212,107 @@ pub fn gen_column(
 // KIND_LIST
 // ---------------------------------------------------------------------------------------------------------------------
 
-lazy_static! {
-    pub static ref KIND_LIST: HashMap<ConfigColumnKind, (&'static str, &'static str)> = [
-        (
-            ConfigColumnKind::Command,
-            ("Command", "Command with all arguments")
-        ),
-        (
-            ConfigColumnKind::ContextSw,
-            ("ContextSw", "Context switch count")
-        ),
-        (
-            ConfigColumnKind::CpuTime,
-            ("CpuTime", "Cumulative CPU time")
-        ),
-        (
-            ConfigColumnKind::Docker,
-            ("Docker", "Docker container name")
-        ),
-        (
-            ConfigColumnKind::ElapsedTime,
-            ("ElapsedTime", "Elapsed time")
-        ),
-        (ConfigColumnKind::Empty, ("Empty", "Empty")),
-        (ConfigColumnKind::Gid, ("Gid", "Group ID")),
-        (ConfigColumnKind::GidReal, ("GidReal", "Real group ID")),
-        (ConfigColumnKind::GidSaved, ("GidSaved", "Saved group ID")),
-        (ConfigColumnKind::Group, ("Group", "Group name")),
-        (
-            ConfigColumnKind::GroupReal,
-            ("GroupReal", "Real group name")
-        ),
-        (
-            ConfigColumnKind::GroupSaved,
-            ("GroupSaved", "Saved group name")
-        ),
-        (
-            ConfigColumnKind::MajFlt,
-            ("MajFlt", "Major page fault count")
-        ),
-        (
-            ConfigColumnKind::MinFlt,
-            ("MinFlt", "Minor page fault count")
-        ),
-        (
-            ConfigColumnKind::MultiSlot,
-            ("MultiSlot", "Slot for `--insert` option")
-        ),
-        (ConfigColumnKind::Nice, ("Nice", "Nice value")),
-        (ConfigColumnKind::Pgid, ("Pgid", "Process group ID")),
-        (ConfigColumnKind::Pid, ("Pid", "Process ID")),
-        (ConfigColumnKind::Policy, ("Policy", "Scheduling policy")),
-        (ConfigColumnKind::Ppid, ("Ppid", "Parent process ID")),
-        (ConfigColumnKind::Priority, ("Priority", "Priority")),
-        (
-            ConfigColumnKind::ReadBytes,
-            ("ReadBytes", "Read bytes from storage")
-        ),
-        (
-            ConfigColumnKind::Separator,
-            ("Separator", "Show | for column separation")
-        ),
-        (
-            ConfigColumnKind::Slot,
-            ("Slot", "Slot for `--insert` option")
-        ),
-        (ConfigColumnKind::StartTime, ("StartTime", "Starting time")),
-        (ConfigColumnKind::State, ("State", "Process state")),
-        (ConfigColumnKind::TcpPort, ("TcpPort", "Bound TCP ports")),
-        (ConfigColumnKind::Threads, ("Threads", "Thread count")),
-        (ConfigColumnKind::Tty, ("Tty", "Controlling TTY")),
-        (ConfigColumnKind::UdpPort, ("UdpPort", "Bound UDP ports")),
-        (ConfigColumnKind::Uid, ("Uid", "User ID")),
-        (ConfigColumnKind::UidReal, ("UidReal", "Real user ID")),
-        (ConfigColumnKind::UidSaved, ("UidSaved", "Saved user ID")),
-        (ConfigColumnKind::UsageCpu, ("UsageCpu", "CPU utilization")),
-        (
-            ConfigColumnKind::UsageMem,
-            ("UsageMem", "Memory utilization")
-        ),
-        (ConfigColumnKind::User, ("User", "User name")),
-        (ConfigColumnKind::UserReal, ("UserReal", "Real user name")),
-        (
-            ConfigColumnKind::UserSaved,
-            ("UserSaved", "Saved user name")
-        ),
-        (ConfigColumnKind::VmRss, ("VmRss", "Resident set size")),
-        (ConfigColumnKind::VmSize, ("VmSize", "Physical page size")),
-        (
-            ConfigColumnKind::WriteBytes,
-            ("WriteBytes", "Write bytes to storage")
-        ),
-    ]
-    .iter()
-    .cloned()
-    .collect();
-}
+pub static KIND_LIST: Lazy<HashMap<ConfigColumnKind, (&'static str, &'static str)>> =
+    Lazy::new(|| {
+        [
+            (
+                ConfigColumnKind::Command,
+                ("Command", "Command with all arguments"),
+            ),
+            (
+                ConfigColumnKind::ContextSw,
+                ("ContextSw", "Context switch count"),
+            ),
+            (
+                ConfigColumnKind::CpuTime,
+                ("CpuTime", "Cumulative CPU time"),
+            ),
+            (
+                ConfigColumnKind::Docker,
+                ("Docker", "Docker container name"),
+            ),
+            (
+                ConfigColumnKind::ElapsedTime,
+                ("ElapsedTime", "Elapsed time"),
+            ),
+            (ConfigColumnKind::Empty, ("Empty", "Empty")),
+            (ConfigColumnKind::Gid, ("Gid", "Group ID")),
+            (ConfigColumnKind::GidReal, ("GidReal", "Real group ID")),
+            (ConfigColumnKind::GidSaved, ("GidSaved", "Saved group ID")),
+            (ConfigColumnKind::Group, ("Group", "Group name")),
+            (
+                ConfigColumnKind::GroupReal,
+                ("GroupReal", "Real group name"),
+            ),
+            (
+                ConfigColumnKind::GroupSaved,
+                ("GroupSaved", "Saved group name"),
+            ),
+            (
+                ConfigColumnKind::MajFlt,
+                ("MajFlt", "Major page fault count"),
+            ),
+            (
+                ConfigColumnKind::MinFlt,
+                ("MinFlt", "Minor page fault count"),
+            ),
+            (
+                ConfigColumnKind::MultiSlot,
+                ("MultiSlot", "Slot for `--insert` option"),
+            ),
+            (ConfigColumnKind::Nice, ("Nice", "Nice value")),
+            (ConfigColumnKind::Pgid, ("Pgid", "Process group ID")),
+            (ConfigColumnKind::Pid, ("Pid", "Process ID")),
+            (ConfigColumnKind::Policy, ("Policy", "Scheduling policy")),
+            (ConfigColumnKind::Ppid, ("Ppid", "Parent process ID")),
+            (ConfigColumnKind::Priority, ("Priority", "Priority")),
+            (
+                ConfigColumnKind::ReadBytes,
+                ("ReadBytes", "Read bytes from storage"),
+            ),
+            (
+                ConfigColumnKind::Separator,
+                ("Separator", "Show | for column separation"),
+            ),
+            (
+                ConfigColumnKind::Slot,
+                ("Slot", "Slot for `--insert` option"),
+            ),
+            (ConfigColumnKind::StartTime, ("StartTime", "Starting time")),
+            (ConfigColumnKind::State, ("State", "Process state")),
+            (ConfigColumnKind::TcpPort, ("TcpPort", "Bound TCP ports")),
+            (ConfigColumnKind::Threads, ("Threads", "Thread count")),
+            (
+                ConfigColumnKind::TreeSlot,
+                ("TreeSlot", "Slot for tree column"),
+            ),
+            (ConfigColumnKind::Tty, ("Tty", "Controlling TTY")),
+            (ConfigColumnKind::UdpPort, ("UdpPort", "Bound UDP ports")),
+            (ConfigColumnKind::Uid, ("Uid", "User ID")),
+            (ConfigColumnKind::UidReal, ("UidReal", "Real user ID")),
+            (ConfigColumnKind::UidSaved, ("UidSaved", "Saved user ID")),
+            (ConfigColumnKind::UsageCpu, ("UsageCpu", "CPU utilization")),
+            (
+                ConfigColumnKind::UsageMem,
+                ("UsageMem", "Memory utilization"),
+            ),
+            (ConfigColumnKind::User, ("User", "User name")),
+            (ConfigColumnKind::UserReal, ("UserReal", "Real user name")),
+            (
+                ConfigColumnKind::UserSaved,
+                ("UserSaved", "Saved user name"),
+            ),
+            (ConfigColumnKind::VmRss, ("VmRss", "Resident set size")),
+            (ConfigColumnKind::VmSize, ("VmSize", "Physical page size")),
+            (
+                ConfigColumnKind::WriteBytes,
+                ("WriteBytes", "Write bytes to storage"),
+            ),
+        ]
+        .iter()
+        .cloned()
+        .collect()
+    });
 
 // ---------------------------------------------------------------------------------------------------------------------
 // CONFIG_DEFAULT
@@ -456,6 +465,9 @@ style = "White"
 kind = "Threads"
 style = "White"
 [[columns]]
+kind = "TreeSlot"
+style = "BrightWhite"
+[[columns]]
 kind = "Tty"
 style = "White"
 [[columns]]
