@@ -1,14 +1,46 @@
 use crate::column::Column;
 use crate::columns::{ConfigColumnKind, KIND_LIST};
-use crate::config::{Config, ConfigColumnAlign, ConfigSearchLogic, ConfigTheme};
+use crate::config::{Config, ConfigColumnAlign, ConfigSearchCase, ConfigSearchLogic, ConfigTheme};
 use crate::Opt;
 use atty::Stream;
 use byte_unit::Byte;
+use clap::ValueEnum;
 use std::borrow::Cow;
 use std::time::Duration;
 use std::time::Instant;
 use unicode_width::{UnicodeWidthChar, UnicodeWidthStr};
 
+#[derive(ValueEnum, Copy, Clone, Debug, PartialEq)]
+pub enum ArgColorMode {
+    Auto,
+    Always,
+    Disable,
+}
+
+#[derive(ValueEnum, Copy, Clone, Debug, PartialEq)]
+pub enum ArgThemeMode {
+    Auto,
+    Dark,
+    Light,
+}
+
+impl From<ArgThemeMode> for ConfigTheme {
+    fn from(item: ArgThemeMode) -> Self {
+        match item {
+            ArgThemeMode::Auto => ConfigTheme::Auto,
+            ArgThemeMode::Dark => ConfigTheme::Dark,
+            ArgThemeMode::Light => ConfigTheme::Light,
+        }
+    }
+}
+
+#[derive(ValueEnum, Copy, Clone, Debug, PartialEq)]
+pub enum ArgPagerMode {
+    Auto,
+    Always,
+    Disable,
+}
+
 pub enum KeywordClass {
     Numeric,
     NonNumeric,
@@ -19,6 +51,7 @@ pub fn find_partial<T: AsRef<str>>(
     pid: i32,
     keyword: &[T],
     logic: &ConfigSearchLogic,
+    case: &ConfigSearchCase,
 ) -> bool {
     let mut ret = match logic {
         ConfigSearchLogic::And => true,
@@ -28,8 +61,23 @@ pub fn find_partial<T: AsRef<str>>(
     };
     for w in keyword {
         let mut hit = false;
+        let keyword = w.as_ref();
+        let keyword_lowercase = keyword.to_ascii_lowercase();
+
+        let ignore_case = match case {
+            ConfigSearchCase::Smart => keyword == keyword.to_ascii_lowercase(),
+            ConfigSearchCase::Insensitive => true,
+            ConfigSearchCase::Sensitive => false,
+        };
+
+        let (keyword, content_to_lowercase) = if ignore_case {
+            (keyword_lowercase.as_str(), true)
+        } else {
+            (keyword, false)
+        };
+
         for c in columns {
-            if c.find_partial(pid, w.as_ref()) {
+            if c.find_partial(pid, keyword, content_to_lowercase) {
                 hit = true;
                 break;
             }
@@ -49,6 +97,7 @@ pub fn find_exact<T: AsRef<str>>(
     pid: i32,
     keyword: &[T],
     logic: &ConfigSearchLogic,
+    case: &ConfigSearchCase,
 ) -> bool {
     let mut ret = match logic {
         ConfigSearchLogic::And => true,
@@ -58,8 +107,23 @@ pub fn find_exact<T: AsRef<str>>(
     };
     for w in keyword {
         let mut hit = false;
+        let keyword = w.as_ref();
+        let keyword_lowercase = keyword.to_ascii_lowercase();
+
+        let ignore_case = match case {
+            ConfigSearchCase::Smart => keyword == keyword.to_ascii_lowercase(),
+            ConfigSearchCase::Insensitive => true,
+            ConfigSearchCase::Sensitive => false,
+        };
+
+        let (keyword, content_to_lowercase) = if ignore_case {
+            (keyword_lowercase.as_str(), true)
+        } else {
+            (keyword, false)
+        };
+
         for c in columns {
-            if c.find_exact(pid, w.as_ref()) {
+            if c.find_exact(pid, keyword, content_to_lowercase) {
                 hit = true;
                 break;
             }
@@ -240,13 +304,8 @@ pub fn lap(instant: &mut Instant, msg: &str) {
 }
 
 pub fn get_theme(opt: &Opt, config: &Config) -> ConfigTheme {
-    let theme = match (opt.theme.as_ref(), &config.display.theme) {
-        (Some(x), _) => match x.as_str() {
-            "auto" => ConfigTheme::Auto,
-            "dark" => ConfigTheme::Dark,
-            "light" => ConfigTheme::Light,
-            _ => unreachable!(),
-        },
+    let theme = match (opt.theme, &config.display.theme) {
+        (Some(x), _) => x.into(),
         (_, x) => x.clone(),
     };
     match theme {
